@@ -11,6 +11,7 @@ Custom Tk widgets for SEAMM.
 from seamm_widgets.mousewheel_support import MousewheelSupport  # noqa: F401
 from seamm_widgets.labeled_widget import LabeledWidget, align_labels  # noqa: F401, E501
 from seamm_widgets.scrolled_frame import ScrolledFrame  # noqa: F401
+from seamm_widgets.scrolled_labelframe import ScrolledLabelFrame  # noqa: F401
 from seamm_widgets.scrolled_columns import ScrolledColumns  # noqa: F401
 from seamm_widgets.keywords import Keywords  # noqa: F401
 from seamm_widgets.property_table import PropertyTable  # noqa: F401
@@ -19,6 +20,8 @@ from seamm_widgets.labeled_combobox import LabeledCombobox  # noqa: F401
 from seamm_widgets.periodic_table import PeriodicTable  # noqa: F401
 from seamm_widgets.unit_entry import UnitEntry  # noqa: F401
 from seamm_widgets.unit_combobox import UnitCombobox  # noqa: F401
+from seamm_widgets.search_criteria import Criterion  # noqa: F401
+from seamm_widgets.search_criteria import SearchCriteria  # noqa: F401
 
 # Handle versioneer
 from ._version import get_versions
@@ -33,6 +36,7 @@ del get_versions, versions
 default_units = {
     "dimensionless": ["degree"],
     "[length]": ["Å", "pm", "nm", "um"],
+    "[length] ** 2": ["Å**2", "pm**2", "nm**2", "um**2"],
     "[length] ** 3": ["Å**3", "pm**3", "nm**3", "um**3"],
     "[mass]": ["g", "kg", "tonne", "lb", "ton"],
     "[substance]": ["mol"],
